use std::{ffi::OsString, fs};
pub fn gen_head(charset: &str, author: &str, title: &str, stylesheet: &str) -> String {
    String::from(format!(r#"
    <head>
        <meta charset="{}" />
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <meta name="author" content="{}">
        <title>{}</title>
        <link rel="stylesheet" href="./styles/{}.css">
    </head>
"#, charset, author, title, stylesheet))}

pub fn gen_header(site_name: &str, quote: String) -> String {
    let blinkie_string = gen_imgs("blinkies");
    String::from(format!(r#"
    <header>
        <div class="header-greet">welcome to...</div>
        <h1>{}</h1>
        <div id="header-quotebox" class="window">
            <div class="billboard">{}</div>
        </div>
        <div id="blinkiebox">
            <div class="marquee"><div class="blinkies">{}</div><div class="blinkies">{}</div></div>
        </div>
    </header>
"#, site_name, quote, blinkie_string, blinkie_string))}

pub fn gen_main(nav: String, content: String) -> String {
    String::from(format!(r#"
    <main>
        {}
        {}
    </main>
"#, nav, content))
}

pub fn gen_footer() -> String {
    let banners_string = gen_imgs("banners");
    String::from(format!(r#"
    <footer>
        <div id="bannerbox">
            <div class="marquee"><div class="banners">{}</div><div class="banners">{}</div></div>
        </div>
    </footer>
"#, banners_string, banners_string))}

pub fn gen_nav(links_map: Vec<(&str, &str)>) -> String{
    let mut links:String = String::from("");
    for (url, label) in links_map.into_iter() {
        let mut newtab = "";
        if url.chars().nth(0).unwrap() != '/' {
            newtab = "target='_blank'"
        }
        let link_tag = format!("<li><a class='navlink' {} href='{}'>{}</a></li>", newtab ,url, label);
        links = format!("{links}{link_tag}");
    }

    String::from(format!(r#"
    <nav class="window">
        <h2 style="color: rgb(222,222,108);">travel to...</h2>
        <ul>
            {}
        </ul>
    </nav>
"#, links))}

// use for when no content for main availiable
pub fn gen_placeholder() -> String{
    String::from(format!(r#"
    <article>
        <div class="window">
            <h2>!under construction!</h2>
        </div>
    </article>
"#))}

fn gen_imgs(images: &str) -> String {
    let paths = fs::read_dir(format!("./static/img/{images}/")).unwrap();
    let mut imgs:String = String::from("");

    for path in paths {
        let file_name = OsString::from(path.unwrap().file_name());
        let img_tag = format!("<img src='./img/{images}/{}'>", file_name.to_str().unwrap());
        imgs = format!("{imgs}{img_tag}");
    }

    return imgs;
}

//content
pub fn home_content() -> String {
    String::from(format!(r#"
    <article>
        <div class="window">
            <h2 style="color: rgb(222,222,108);">welcome!</h2>
            <p>hiii!!! welcome to my site, feel free to look around and learn something your government doesn't want you to :3</p>
        </div>
        <div class="window" style="max-width: 400px;">
            <h2>stampbook</h2>
            <div class="stamps">
                {}
            </div>
        </div>
    </article>
"#, gen_imgs("stamps")))}